@@ -7,6 +7,7 @@ import adafruit_tmp006
 def c_to_f(c):
     return c * 9.0 / 5.0 + 32.0
 
+
 # Create library object using our Bus I2C port
 i2c = busio.I2C(board.SCL, board.SDA)
 sensor = adafruit_tmp006.TMP006(i2c)
@@ -16,5 +17,7 @@ sensor = adafruit_tmp006.TMP006(i2c)
 # The first sample will be meaningless
 while True:
     obj_temp = sensor.temperature
-    print('Object temperature: {0:0.3F}*C / {1:0.3F}*F'.format(obj_temp, c_to_f(obj_temp)))
+    print(
+        "Object temperature: {0:0.3F}*C / {1:0.3F}*F".format(obj_temp, c_to_f(obj_temp))
+    )
     time.sleep(5.0)
